package main

import (
	"github.com/google/uuid"
	"github.com/uptrace/bun"
)

type UserModel struct {
	bun.BaseModel `bun:"table:users"`

	UUID          uuid.UUID `bun:"user_uuid,pk"`
	Username      string    `bun:"user_name"`
	IsExperienced bool      `bun:"user_is_experienced"`
	IsTrusted     bool      `bun:"user_is_trusted"`
	// https://pkg.go.dev/github.com/google/uuid#UUID
	// SELECT user_uuid,user_name,user_is_experienced,user_is_trusted FROM \
	// users ORDER BY user_uuid;
}

type SSHKeyModel struct {
	bun.BaseModel `bun:"table:ssh_keys"`

	UUID      uuid.UUID `bun:"ssh_key_uuid,pk"`
	Username  string    `bun:"ssh_key_user_name"`
	PublicKey []byte    `bun:"ssh_key_public_key"`
	// https://pkg.go.dev/golang.org/x/crypto/ssh#PublicKey
	// SELECT ssh_key_uuid,ssh_key_user_name FROM ssh_keys ORDER BY ssh_key_user_name;
}

type ServerModel struct {
}

type ServerDefinitionModel struct {
}

type ManifestModel struct {
	bun.BaseModel `bun:"table:manifests"`

	UUID    uuid.UUID `bun:"mainifest_uuid,pk"`
	Name    string    `bun:"manifest_name"`
	LastRan string    `bun:"manifest_last_ran"`
	XML     string    `bun:"manifest_xml"`
	Note    string    `bun:"manifest_note"`
	// https://pkg.go.dev/encoding/xml#CharData
}

type JobModel struct {
	bun.BaseModel `bun:"table:jobs"`

	UUID        uuid.UUID `bun:"job_uuid,pk"`
	HostUUID    uuid.UUID `bun:"host_uuid"`
	Command     string    `bun:"job_command"`
	Data        string    `bun:"job_data"`
	PickedUpBy  string    `bun:"job_picked_up_by"`
	PickedUpAt  string    `bun:"job_picked_up_at"`
	Updated     string    `bun:"job_updated"`
	Name        string    `bun:"job_name"`
	Progress    int64     `bun:"job_progress"`
	Title       string    `bun:"job_title"`
	Description string    `bun:"job_description"`
	Status      string    `bun:"job_status"`
}

type HostModel struct {
	bun.BaseModel `bun:"table:hosts"`

	UUID       uuid.UUID `bun:"host_uuid,pk"`
	HostName   string    `bun:"host_name"`
	HostType   string    `bun:"host_type"`
	HostKey    string    `bun:"host_key"`
	HostIPMI   string    `bun:"host_ipmi"`
	HostStatus string    `bun:"host_status"`
}
